@@ -19,14 +19,11 @@ urlpatterns = patterns('',
     url(r"^recipient-search/$", recipient_search, name="recipient_search"),
     url(r'^message-reply/(?P<thread_id>[\d]+)/$', message_ajax_reply, name="message_reply"),
 
-    # modal composing
-    url(r'^modal-compose/(?P<recipient>[\w.+-_]+)/$', compose, {
-                            "template_name":"django_messages/modal_compose.html",
-                            "form_class": ComposeForm
-                        }, name='modal_messages_compose_to'),
-
     url(r'^modal-compose/$', compose, {
-                            "template_name":"django_messages/modal_compose.html",
-                            "form_class": ComposeForm
-                        }, name='modal_messages_compose'),
+        "template_name": "django_messages/modal_compose.html",
+    }, name='modal_messages_compose'),
+
+    url(r'^modal-compose/(?P<recipient>[\w.+-_]+)/$', compose, {
+        "template_name": "django_messages/modal_compose.html",
+    }, name='modal_messages_compose_to'),
 )
